package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.GtgsZx;
import com.ruoyi.system.mapper.GtgsZxMapper;
import com.ruoyi.system.service.IGtgsZxService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.core.text.Convert;

/**
 * 注销前台Service业务层处理
 * 
 * @author ruoyi
 * @date 2020-05-13
 */
@Service
public class GtgsZxServiceImpl implements IGtgsZxService
{
    @Autowired
    private GtgsZxMapper gtgsZxMapper;

    /**
     * 查询注销前台
     * 
     * @param id 注销前台ID
     * @return 注销前台
     */
    @Override
    public GtgsZx selectGtgsZxById(String id)
    {
        return gtgsZxMapper.selectGtgsZxById(id);
    }

    /**
     * 查询注销前台列表
     * 
     * @param gtgsZx 注销前台
     * @return 注销前台
     */
    @Override
    public List<GtgsZx> selectGtgsZxList(GtgsZx gtgsZx)
    {
        return gtgsZxMapper.selectGtgsZxList(gtgsZx);
    }

    /**
     * 新增注销前台
     * 
     * @param gtgsZx 注销前台
     * @return 结果
     */
    @Override
    public int insertGtgsZx(GtgsZx gtgsZx)
    {
        gtgsZx.setCreateTime(DateUtils.getNowDate());
        return gtgsZxMapper.insertGtgsZx(gtgsZx);
    }

    /**
     * 修改注销前台
     * 
     * @param gtgsZx 注销前台
     * @return 结果
     */
    @Override
    public int updateGtgsZx(GtgsZx gtgsZx)
    {
        return gtgsZxMapper.updateGtgsZx(gtgsZx);
    }

    @Override
    public int changeGtgsZxFlagTg(GtgsZx gtgsZx) {
        return gtgsZxMapper.changeGtgsZxFlagTg(gtgsZx);
    }

    /**
     * 删除注销前台对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteGtgsZxByIds(String ids)
    {
        return gtgsZxMapper.deleteGtgsZxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除注销前台信息
     * 
     * @param id 注销前台ID
     * @return 结果
     */
    public int deleteGtgsZxById(String id)
    {
        return gtgsZxMapper.deleteGtgsZxById(id);
    }
}
